@@ -5,6 +5,7 @@ Currently PDF and PGF are supported in a multipage backend.
 Written by Eben Pendleton
 MIT License
 """
+
 # used to deep copy config
 import copy
 # used in metadata
@@ -15,12 +16,14 @@ import os
 
 # backend for display in GitHub Actions
 if os.environ.get('DISPLAY','') == '':
-    import matplotlib as mpl
     print('no display found. Using non-interactive Agg backend')
-    mpl.use('Agg')
+    import matplotlib
+    matplotlib.use('Agg')
 
 # used to draw lines on the figure
-import matplotlib.lines as lines
+import matplotlib.lines as lines  # isort: split
+# used to validate and read in ini files
+import configobj
 # matplotlib import used in setting figure and axes
 import matplotlib.pyplot as plt
 # import package resources to get ini
@@ -29,9 +32,6 @@ import pkg_resources
 from matplotlib.backends.backend_pdf import PdfPages
 # used to set the plot layout in the figure
 from matplotlib.gridspec import GridSpec
-
-# used to validate and read in ini files
-import configobj
 # import the validator
 from validate import Validator
 
@@ -64,7 +64,6 @@ def float_list_value(v, minl=None, maxl=None, minv=None, maxv=None):
 
     return [is_float(mem, min=minv, max=maxv) for mem in is_list(v, minl, maxl)]
 
-
 class FigPager:
 
     """ Class to use matplotlib's figure with multi and single page outputs """
@@ -74,7 +73,7 @@ class FigPager:
     path = os.path.abspath(__file__)
 
     # used to find ini files saved in the package
-    page_layout_path = pkg_resources.resource_filename('figpager', 'page_layout/')
+    page_layout_path = pkg_resources.resource_filename("figpager", "page_layout/")
 
     def __init__(
         self,
@@ -161,14 +160,12 @@ class FigPager:
                         raise IOError(
                             "Output file already exists and user chose not to overwrite."
                         )
-                # hold file type
-                self.type = os.path.splitext(outfile)[1][1:]
+            # hold file type
+            self.type = os.path.splitext(outfile)[1][1:]
 
             # hold outfile full path
             self.outfile = outfile
 
-
-
         # hold multipage indicator
         self.multipage = False
         if self.type in ["pdf", "pgf"]:
@@ -204,8 +201,7 @@ class FigPager:
 
             # read in the ini file of paper sizes
             config = configobj.ConfigObj(
-                os.path.join(self.page_layout_path, "paper_sizes.ini"),
-                configspec=spec,
+                os.path.join(self.page_layout_path, "paper_sizes.ini"), configspec=spec,
             )
 
             # validate against the config above
@@ -248,8 +244,6 @@ class FigPager:
 
         # save current filename as possible next filename base if not multipage
         self.new_fname = self.outfile
-        # list to append multiple filenames
-        self.newfnameall = []
 
         # saves current figure count for use in non multipage
         self.fignumber = 1
@@ -434,7 +428,6 @@ class FigPager:
                 "rotation": "integer",
                 "line_position_start": "float_list_value",
                 "line_position_end": "float_list_value",
-                "line_position_offset": "float_list_value",
                 "line_min": "float",
                 "line_max": "float",
                 "line_length": "string",
@@ -443,7 +436,6 @@ class FigPager:
                 "linestyle": "string",
                 "image_path": "string",
                 "image_position": "float_list_value",
-                "image_position_offset": "float_list_value",
             }
 
             data = myfile.read()
@@ -537,6 +529,30 @@ class FigPager:
             except KeyError:
                 return None
 
+    def _parse_option(self, section, subsection, option):
+
+        """
+        Parse a given config option given the file's section, subsection and option.
+        Return None if option is not found
+        Args:
+            section: config file section. [example]
+            subsection: config file subsection. [[example]]
+            option: config file option. example=True
+
+        Returns: option value or None
+
+        """
+
+        try:
+            return self.config[section][subsection][option]
+        except KeyError:
+            try:
+                return self.config[section][subsection][self.paper_size.title()][
+                    self.orientation.title()
+                ][option]
+            except KeyError:
+                return None
+
     def _update_from_layout(self):
 
         """
@@ -578,43 +594,7 @@ class FigPager:
 
             self.marginframe = self._parse_option("Layout", "Margin", "margin_frame")
             if self.marginframe:
-                self.constrained_layout = False
-                self.leftmargin = (
-                    self._parse_option("Layout", "Margin", "left_margin")
-                    * self.figure_unit_conversion
-                )
-                self.rightmargin = (
-                    self._parse_option("Layout", "Margin", "right_margin")
-                    * self.figure_unit_conversion
-                )
-                self.topmargin = (
-                    self._parse_option("Layout", "Margin", "top_margin")
-                    * self.figure_unit_conversion
-                )
-                self.bottommargin = (
-                    self._parse_option("Layout", "Margin", "bottom_margin")
-                    * self.figure_unit_conversion
-                )
-                self.marginpad = (
-                    self._parse_option("Layout", "Margin", "margin_pad")
-                    * self.figure_unit_conversion
-                )
-
-                self.framewidth = (
-                    self.pagewidth_inch - self.leftmargin - self.rightmargin
-                )
-                self.frameheight = (
-                    self.pageheight_inch - self.topmargin - self.bottommargin
-                )
-            else:
-                self.leftmargin = 0
-                self.rightmargin = 0
-                self.topmargin = 0
-                self.bottommargin = 0
-                self.marginpad = 0
-                self.framewidth = self.pagewidth_inch
-                self.frameheight = self.pageheight_inch
-
+                self._update_marginframe_from_layout()
 
             self.source_path = self._parse_option("Layout", "Margin", "source_path")
             self.source_path_position = [
@@ -631,7 +611,38 @@ class FigPager:
             # read text
             self.configtext = self.config["Text"]
 
-    def _text_from_label(self, section, label, txt):
+    def _update_marginframe_from_layout(self):
+        """
+        Update the mergin frame to what's in the current layout config.
+        Returns: None
+
+        """
+        self.constrained_layout = False
+        self.leftmargin = (
+            self._parse_option("Layout", "Margin", "left_margin")
+            * self.figure_unit_conversion
+        )
+        self.rightmargin = (
+            self._parse_option("Layout", "Margin", "right_margin")
+            * self.figure_unit_conversion
+        )
+        self.topmargin = (
+            self._parse_option("Layout", "Margin", "top_margin")
+            * self.figure_unit_conversion
+        )
+        self.bottommargin = (
+            self._parse_option("Layout", "Margin", "bottom_margin")
+            * self.figure_unit_conversion
+        )
+        self.marginpad = (
+            self._parse_option("Layout", "Margin", "margin_pad")
+            * self.figure_unit_conversion
+        )
+
+        self.framewidth = self.pagewidth_inch - self.leftmargin - self.rightmargin
+        self.frameheight = self.pageheight_inch - self.topmargin - self.bottommargin
+
+    def _text_at_label(self, section, label, txt):
 
         """
         Find label and write text at label position with label font characteristics
@@ -794,23 +805,6 @@ class FigPager:
         """
         pos = self._parse_option("Lines", label, "line_position_start")
         pos2 = self._parse_option("Lines", label, "line_position_end")
-
-        if self._parse_option("Lines", label, "image_position_offset") is not None:
-            pos[0] = pos[0] + float(
-                self._parse_option("Images", label, "image_position_offset")[0]
-            )
-            pos[1] = pos[1] + float(
-                self._parse_option("Images", label, "image_position_offset")[1]
-            )
-
-            pos2[0] = pos2[0] + float(
-                self._parse_option("Images", label, "image_position_offset")[0]
-            )
-            pos2[1] = pos2[1] + float(
-                self._parse_option("Images", label, "image_position_offset")[1]
-            )
-
-
         l1 = lines.Line2D(
             [pos[0] / self.pagewidth_inch, pos2[0] / self.pagewidth_inch],
             [pos[1] / self.pageheight_inch, pos2[1] / self.pageheight_inch],
@@ -836,15 +830,6 @@ class FigPager:
         """
         pos = self._parse_option("Images", label, "image_position")
         fname = self._parse_option("Images", label, "image_path")
-
-        if self._parse_option("Images", label, "image_position_offset") is not None:
-            pos[0] = pos[0] + float(
-                self._parse_option("Images", label, "image_position_offset")[0]
-            )
-            pos[1] = pos[1] + float(
-                self._parse_option("Images", label, "image_position_offset")[1]
-            )
-
         if fname:
             filename, file_extension = os.path.splitext(fname)
             img = plt.imread(fname, format=file_extension)
@@ -854,7 +839,6 @@ class FigPager:
             width, height = self.fig.get_size_inches() * self.fig.get_dpi()
             # We're specifying the position and size in figure coordinates, so the image
             # will shrink/grow as the figure is resized.
-            # zorder = 1 places the images on top
             ax = self.fig.add_axes(
                 [
                     pos[0] / self.pagewidth_inch,
@@ -862,12 +846,12 @@ class FigPager:
                     width1 / width,
                     height1 / height,
                 ],
-                anchor="SW",zorder=1,
+                anchor="SW",
             )
             ax.imshow(img)
             ax.axis("off")
 
-    def text_from_label(self, label, txt):
+    def text_at_label(self, label, txt):
         """
                Public function to find label and write text at label position with label font characteristics.
                Assumes label is in text section
@@ -879,7 +863,7 @@ class FigPager:
                Returns: None
 
         """
-        return self._text_from_label("Text", label, txt)
+        return self._text_at_label("Text", label, txt)
 
     def draw_page(self):
         """
@@ -899,7 +883,9 @@ class FigPager:
         fig, ax = plt.subplots(
             constrained_layout=self.constrained_layout,
             figsize=(self.pagewidth_inch, self.pageheight_inch),
-            squeeze=False, sharex=self.sharex, sharey=self.sharey,
+            squeeze=False,
+            sharex=self.sharex,
+            sharey=self.sharey,
         )
 
         # set the patch here
@@ -1013,19 +999,21 @@ class FigPager:
                 bottom=(self.bottommargin + self.marginpad) / self.pageheight_inch,
                 top=(self.frameheight + self.bottommargin - self.marginpad)
                 / self.pageheight_inch,
-                hspace=self.hspace, wspace=self.wspace,
+                hspace=self.hspace,
+                wspace=self.wspace,
             )
 
-        # This resets the margins and other parameters to layout
+        # This resets the margins to the margin layout
         if self.marginframe:
-            self._update_from_layout()
+            self._update_marginframe_from_layout()
 
         # add any layout set text here
         for k in self.config["Text"].keys():
             if self._parse_option("Text", k, "text") is not None:
-                if 'draft' in self._parse_option("Text", k, "text").lower():
-                    if not self.draft: continue
-                self._text_from_label("Text", k, self._parse_option("Text", k, "text"))
+                if "draft" in self._parse_option("Text", k, "text").lower():
+                    if not self.draft:
+                        continue
+                self._text_at_label("Text", k, self._parse_option("Text", k, "text"))
 
         # add any layout set images here
         for k in self.config["Images"].keys():
@@ -1039,9 +1027,10 @@ class FigPager:
         for k in self.config["Watermark"].keys():
             if self._parse_option("Watermark", k, "text") is not None:
                 # check for draft watermark status and whether user has overridden it
-                if 'draft' in self._parse_option("Watermark", k, "text").lower():
-                    if not self.draft: continue
-                self._text_from_label(
+                if "draft" in self._parse_option("Watermark", k, "text").lower():
+                    if not self.draft:
+                        continue
+                self._text_at_label(
                     "Watermark", k, self._parse_option("Watermark", k, "text")
                 )
 
@@ -1091,7 +1080,6 @@ class FigPager:
                         # self.subplotstartindex = pos
                         self.currentsubplotindex = pos
 
-
             if self.direction == "top-to-bottom":
                 if self.subplotstartindex is None:
                     pos = [0, 0]
@@ -1129,7 +1117,7 @@ class FigPager:
         if gs is None:
             return self.fig.add_subplot(
                 self.gs[pos[0], pos[1]],
-                label="({},{}, {})".format(pos[0], pos[1],  self.subplotcounter),
+                label="({},{}, {})".format(pos[0], pos[1], self.subplotcounter),
                 **kwargs
             )
         else:
@@ -1141,8 +1129,10 @@ class FigPager:
             return self.fig.add_subplot(
                 gs,
                 label="({},{}, {})".format(
-                    self.currentsubplotindex[0], self.currentsubplotindex[1],
-                    self.subplotcounter),
+                    self.currentsubplotindex[0],
+                    self.currentsubplotindex[1],
+                    self.subplotcounter,
+                ),
                 **kwargs
             )
 
@@ -1202,48 +1192,6 @@ class FigPager:
         Returns: fig; figure instance, ax; axes instances, gs; GridSpec, self.transform; Figure Transform
 
         """
-
-        if self.type in ["pdf", "pgf"]:
-            try:
-                self.pdf.savefig(
-                    self.fig,
-                    dpi=self.dpi,
-                    facecolor=self.facecolor,
-                    edgecolor=self.edgecolor,
-                    orientation=self.orientation,
-                    transparent=self.transparent,
-                    bbox_inches=self.bbox_inches,
-                    pad_inches=self.pad_inches,
-                    metadata=self.metadata,
-                )
-            except AttributeError as a:
-                if str(a) == "'NoneType' object has no attribute 'endStream'":
-                    raise AttributeError("Cannot add a new page to a closed pdf file.")
-        elif self.type is not None:
-            # number 02, 03 etc '{:02}'.format(1)
-            plt.savefig(
-                self.new_fname,
-                dpi=self.dpi,
-                facecolor=self.facecolor,
-                edgecolor=self.edgecolor,
-                orientation=self.orientation,
-                transparent=self.transparent,
-                bbox_inches=self.bbox_inches,
-                pad_inches=self.pad_inches,
-                metadata=self.metadata,
-            )
-            # append multiple filenames
-            self.newfnameall.append(self.new_fname)
-
-            filename, file_extension = os.path.splitext(self.outfile)
-            self.fignumber = self.fignumber + 1
-            self.new_fname = "{}_{}{}".format(
-                filename, "{:02}".format(self.fignumber), file_extension
-            )
-        else:
-            plt.show()
-        plt.close(self.fig)
-
         if paper_size is not None:
             self.paper_size = paper_size
 
@@ -1312,6 +1260,44 @@ class FigPager:
             # update from layout
             self._update_from_layout()
 
+        if self.type in ["pdf", "pgf"]:
+            try:
+                self.pdf.savefig(
+                    self.fig,
+                    dpi=self.dpi,
+                    facecolor=self.facecolor,
+                    edgecolor=self.edgecolor,
+                    orientation=self.orientation,
+                    transparent=self.transparent,
+                    bbox_inches=self.bbox_inches,
+                    pad_inches=self.pad_inches,
+                    metadata=self.metadata,
+                )
+            except AttributeError as a:
+                if str(a) == "'NoneType' object has no attribute 'endStream'":
+                    raise AttributeError("Cannot add a new page to a closed pdf file.")
+        elif self.type is not None:
+            # probably number 02, 03 etc '{:02}'.format(1)
+            plt.savefig(
+                self.new_fname,
+                dpi=self.dpi,
+                facecolor=self.facecolor,
+                edgecolor=self.edgecolor,
+                orientation=self.orientation,
+                transparent=self.transparent,
+                bbox_inches=self.bbox_inches,
+                pad_inches=self.pad_inches,
+                metadata=self.metadata,
+            )
+
+            filename, file_extension = os.path.splitext(self.outfile)
+            self.fignumber = self.fignumber + 1
+            self.new_fname = "{}_{}{}".format(
+                filename, "{:02}".format(self.fignumber), file_extension
+            )
+        else:
+            plt.show()
+        plt.close(self.fig)
         self.fig, self.ax, self.gs, self.transform = self.draw_page()
 
         return self.fig, self.ax, self.gs, self.transform
@@ -1337,11 +1323,6 @@ class FigPager:
                     pad_inches=self.pad_inches,
                     metadata=self.metadata,
                 )
-                self.newfnameall.append(self.new_fname)
-
-                # update the outfile name if needed
-                if self.newfnameall:
-                    self.outfile = '\n'.join(self.newfnameall)
             else:
                 self.pdf.savefig(
                     self.fig,
@@ -1366,8 +1347,6 @@ class FigPager:
 
                 # Remember to close the object - otherwise the file will not be usable
                 self.pdf.close()
-
-
         else:
             plt.show()
             plt.close(self.fig)
